Struct plaid::link_token::CreateLinkTokenResponse[][src]

pub struct CreateLinkTokenResponse {
    pub request_id: String,
    pub link_token: String,
    pub expiration: DateTime<Utc>,
}

Fields

request_id: String

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

link_token: String

A link_token, which can be supplied to Link in order to initialize it and receive a public_token, which can be exchanged for an access_token.

expiration: DateTime<Utc>

The expiration date for the link_token, in ISO 8601 format.