Struct plaid::link_token::GetLinkTokenResponse [−][src]
Fields
request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
link_token: StringA link_token, which can be supplied to Link in order to initialize it and receive a public_token, which can be exchanged for an access_token.
created_at: Option<DateTime<Utc>>The creation timestamp for the link_token, in ISO 8601 format.
expiration: Option<DateTime<Utc>>The expiration timestamp for the link_token, in ISO 8601 format.
metadata: GetLinkTokenMetadataResponseAn object specifying the arguments originally provided to the /link/token/create call.