Struct plaid::link_token::LinkTokenUser[][src]

pub struct LinkTokenUser<'a> {
    pub client_user_id: &'a str,
    pub legal_name: Option<&'a str>,
    pub phone_number: Option<&'a str>,
    pub phone_number_verified_time: Option<DateTime<Utc>>,
    pub email_address: Option<&'a str>,
    pub email_address_verified_time: Option<DateTime<Utc>>,
    pub ssn: Option<&'a str>,
    pub date_of_birth: Option<&'a str>,
}

Fields

client_user_id: &'a str

A unique ID representing the end user.

legal_name: Option<&'a str>

The user's full legal name. This is an optional field used in the returning user experience to associate Items to the user.

phone_number: Option<&'a str>

The user's phone number in E.164 format. This field is optional, but required to enable the returning user experience.

phone_number_verified_time: Option<DateTime<Utc>>

The date and time the phone number was verified in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). This field is optional, but required to enable any returning user experience.

email_address: Option<&'a str>

The user's email address. This field is optional, but required to enable the pre-authenticated returning user flow.

email_address_verified_time: Option<DateTime<Utc>>

The date and time the email address was verified in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). This is an optional field used in the returning user experience.

ssn: Option<&'a str>

To be provided in the format "ddd-dd-dddd". This field is optional and will support not-yet-implemented functionality for new products.

date_of_birth: Option<&'a str>

To be provided in the format "yyyy-mm-dd". This field is optional and will support not-yet-implemented functionality for new products.