Struct plaid::link_token::LinkTokenConfigs [−][src]
Fields
user: LinkTokenUser<'a>An object specifying information about the end user who will be linking their account.
client_name: &'a strThe name of your application, as it should be displayed in Link.
language: &'a strThe language that Link should be displayed in.
country_codes: &'a [&'a str]Specify an array of Plaid-supported country codes using the ISO-3166-1 alpha-2 country code standard.
products: Option<&'a [&'a str]>List of Plaid product(s) you wish to use.
webhook: Option<&'a str>The destination URL to which any webhooks should be sent.
access_token: Option<&'a str>The access_token associated with the Item to update, used when updating or modifying an existing access_token. Used when launching Link in update mode, when completing the Same-day (manual) Micro-deposit flow, or (optionally) when initializing Link as part of the Payment Initiation (UK and Europe) flow.
link_customization_name: Option<&'a str>The name of the Link customization from the Plaid Dashboard to be applied to Link.
account_filters: Option<HashMap<&'a str, HashMap<&'a str, Vec<&'a str>>>>redirect_uri: Option<&'a str>A URI indicating the destination where a user should be forwarded after completing the Link flow
android_package_name: Option<&'a str>The name of your app's Android package.